function [white_R ,white_G ,white_B,output_data] = general_cc(input_data,njet,norm_value,sigma,error_im)

saturation_threshold = 255;

if(nargin<4), njet=0; end
if(nargin<5), error_im=[];end
if(size(error_im,1)==0), error_im=zeros(size(input_data,1),size(input_data,2)) ;end


saturation_removal=0;
if(saturation_removal) % remove all saturated points
    mask_im = error_im + (dilation33(double(max(input_data,[],3)>=saturation_threshold)));   
    mask_im=double(mask_im==0);
    mask_im=set_border(mask_im,sigma+1,0);
else   % no saturation removal 
    mask_im=double(error_im==0);
end
output_data=input_data;

if(njet==0)
   if(sigma~=0)
     for ii=1:3
        input_data(:,:,ii)=gDer(input_data(:,:,ii),sigma,0,0);
     end
   end
end

if(njet>0)
    [Rx,Gx,Bx]=NormDerivative(input_data, sigma, njet);
    
    input_data(:,:,1)=Rx;
    input_data(:,:,2)=Gx;
    input_data(:,:,3)=Bx;    
end

input_data=abs(input_data);

if(norm_value~=-1)          % minkowski norm < infty    
    kleur=power(input_data,norm_value);
 
    white_R = power(sum(sum(kleur(:,:,1).*mask_im)),1/norm_value);
    white_G = power(sum(sum(kleur(:,:,2).*mask_im)),1/norm_value);
    white_B = power(sum(sum(kleur(:,:,3).*mask_im)),1/norm_value);

    som=sqrt(white_R^2+white_G^2+white_B^2);

    white_R=white_R/som;
    white_G=white_G/som;
    white_B=white_B/som;
    
else                        % minkowski-norm is infinit: Max-algorithm     
    
    R=input_data(:,:,1);
    G=input_data(:,:,2);
    B=input_data(:,:,3);
    
    white_R=max(R(:).*mask_im(:));
    white_G=max(G(:).*mask_im(:));
    white_B=max(B(:).*mask_im(:));
    
    som=sqrt(white_R^2+white_G^2+white_B^2);

    white_R=white_R/som;
    white_G=white_G/som;
    white_B=white_B/som;
    
end
output_data(:,:,1)=output_data(:,:,1)/(white_R*sqrt(3));
output_data(:,:,2)=output_data(:,:,2)/(white_G*sqrt(3));
output_data(:,:,3)=output_data(:,:,3)/(white_B*sqrt(3));